@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-08-09'; # DATE
-our $VERSION = '1.26'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '1.27'; # VERSION
 
 use 5.010001;
 use strict;
@@ -293,7 +293,7 @@ _
     # currently work around this via setting env.
     log_level => {
         getopt  => 'log-level=s',
-        summary => 'Set log level',
+        summary => 'Set log level (note: you also need to set LOG=1 to enable logging)',
         schema  => ['str*' => in => [
             qw/trace debug info warn warning error fatal/]],
         handler => sub {
@@ -306,7 +306,7 @@ _
     },
     trace => {
         getopt  => "trace",
-        summary => "Set log level to trace",
+        summary => "Set log level to trace (note: you also need to set LOG=1 to enable logging, or use TRACE=1)",
         handler => sub {
             my ($go, $val, $r) = @_;
             $ENV{TRACE} = 1;
@@ -315,7 +315,7 @@ _
     },
     debug => {
         getopt  => "debug",
-        summary => "Set log level to debug",
+        summary => "Set log level to debug (note: you also need to set LOG=1 to enable logging, or use DEBUG=1)",
         handler => sub {
             my ($go, $val, $r) = @_;
             $ENV{DEBUG} = 1;
@@ -324,7 +324,7 @@ _
     },
     verbose => {
         getopt  => "verbose",
-        summary => "Set log level to info",
+        summary => "Set log level to info (note: you also need to set LOG=1 to enable logging, or use VERBOSE=1)",
         handler => sub {
             my ($go, $val, $r) = @_;
             $ENV{VERBOSE} = 1;
@@ -334,7 +334,7 @@ _
     },
     quiet => {
         getopt  => "quiet",
-        summary => "Set log level to quiet",
+        summary => "Set log level to quiet (note: you also need to set LOG=1 to enable logging, or use QUIET=1)",
         handler => sub {
             my ($go, $val, $r) = @_;
             $ENV{QUIET} = 1;
@@ -438,9 +438,7 @@ sub _detect_completion {
         return 1;
     }
 
-    # assume default is bash
     $r->{shell} //= 'bash';
-
     0;
 }
 
@@ -1400,7 +1398,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.26 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-08-09.
+This document describes version 1.27 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-08-17.
 
 =head1 DESCRIPTION
 
@@ -2300,7 +2298,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
